package terminal

  1. Overview
  2. Docs

Module Terminal.SizeSource

Sourceval sigwinch : int option

The number of the signal used to indicate terminal size changes. None on Windows.

Functions for getting the size of the terminal to which stdout is attached (provided stdout is a TTY).

Sourcetype dimensions = {
  1. rows : int;
  2. columns : int;
}
Sourceval get_dimensions : unit -> dimensions option
Sourceval get_columns : unit -> int option
Sourceval get_rows : unit -> int option