package terminal
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Terminal.SizeSource
The number of the signal used to indicate terminal size changes. None on Windows.
Functions for getting the size of the terminal to which stdout is attached (provided stdout is a TTY).